@@ -237,25 +237,21 @@ impl FromStr for Color {
 
     fn from_str(s: &str) -> Result<Self, Self::Err> {
         if let Some(c) = CSS_COLORS.get(&s.to_lowercase()) {
-            Ok(c.clone())
+            Ok(*c)
+        } else if let Some(captures) = COLOR_REGEX.captures(s) {
+            Ok(Color::from_rgb(
+                captures["r"].parse::<f64>()?/ 100.0,
+                captures["g"].parse::<f64>()?/100.0,
+                captures["b"].parse::<f64>()?/100.0,
+            ))
+        } else if let Some(captures) = CSS_COLOR_REGEX.captures(s) {
+            Ok(Color::from_rgb(
+                u32::from_str_radix(&captures["r"], 16).unwrap() as f64 / 255.0,
+                u32::from_str_radix(&captures["g"], 16).unwrap() as f64 / 255.0,
+                u32::from_str_radix(&captures["b"], 16).unwrap() as f64 / 255.0,
+            ))
         } else {
-            if let Some(captures) = COLOR_REGEX.captures(s) {
-                Ok(Color::from_rgb(
-                    captures["r"].parse::<f64>()?/ 100.0,
-                    captures["g"].parse::<f64>()?/100.0,
-                    captures["b"].parse::<f64>()?/100.0,
-                ))
-            } else {
-                if let Some(captures) = CSS_COLOR_REGEX.captures(s) {
-                    Ok(Color::from_rgb(
-                        u32::from_str_radix(&captures["r"], 16).unwrap() as f64 / 255.0,
-                        u32::from_str_radix(&captures["g"], 16).unwrap() as f64 / 255.0,
-                        u32::from_str_radix(&captures["b"], 16).unwrap() as f64 / 255.0,
-                    ))
-                } else {
-                    Err(Error::CouldntUnderstandColor(s.into()))
-                }
-            }
+            Err(Error::CouldntUnderstandColor(s.into()))
         }
     }
 }
@@ -345,21 +341,21 @@ trait Deserialize {
 
 impl Deserialize for Path{
     fn deserialize(attributes: HashMap<String, String>) -> Result<Box<dyn ShapeStored>, Error> {
-        let styleattr = attributes.get("style").ok_or(Error::MissingAttribute("style".into()))?;
-        let dattr = attributes.get("d").ok_or(Error::MissingAttribute("d".into()))?;
+        let styleattr = attributes.get("style").ok_or_else(|| Error::MissingAttribute("style".into()))?;
+        let dattr = attributes.get("d").ok_or_else(|| Error::MissingAttribute("d".into()))?;
 
-        Ok(Box::new(Path::from_xml_attributes(&styleattr, &dattr)?))
+        Ok(Box::new(Path::from_xml_attributes(styleattr, dattr)?))
     }
 }
 
 impl Deserialize for Ellipse {
     fn deserialize(attributes: HashMap<String, String>) -> Result<Box<dyn ShapeStored>, Error> {
-        let cx = attributes.get("cx").ok_or(Error::MissingAttribute("cx".into()))?;
-        let cy = attributes.get("cy").ok_or(Error::MissingAttribute("cy".into()))?;
-        let rx = attributes.get("rx").ok_or(Error::MissingAttribute("rx".into()))?;
-        let ry = attributes.get("ry").ok_or(Error::MissingAttribute("ry".into()))?;
+        let cx = attributes.get("cx").ok_or_else(|| Error::MissingAttribute("cx".into()))?;
+        let cy = attributes.get("cy").ok_or_else(|| Error::MissingAttribute("cy".into()))?;
+        let rx = attributes.get("rx").ok_or_else(|| Error::MissingAttribute("rx".into()))?;
+        let ry = attributes.get("ry").ok_or_else(|| Error::MissingAttribute("ry".into()))?;
         let angle= attributes.get("transform").map(|s| s.as_str()).unwrap_or("rotate(0)");
-        let styleattr = attributes.get("style").ok_or(Error::MissingAttribute("style".into()))?;
+        let styleattr = attributes.get("style").ok_or_else(|| Error::MissingAttribute("style".into()))?;
 
         let attrs = css_attrs_as_hashmap(styleattr);
 
